cronvice
========

*barebones made by codeframe*

**Purpose:** `cronvice` is

Example
-------

``` {.python}
# example
```

Installation
------------

``` {.bash org-language="sh"}
pip3 install cronvice
```

Usage
-----
